/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -p URfkillKillswitchInterface /home/odroid/lomiri/libqtdbusmock-git/src/libqtdbusmock/data/org.freedesktop.URfkill.Killswitch.xml
 *
 * qdbusxml2cpp is Copyright (C) 2020 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef URFKILLKILLSWITCHINTERFACE_H
#define URFKILLKILLSWITCHINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.URfkill.Killswitch
 */
class OrgFreedesktopURfkillKillswitchInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.URfkill.Killswitch"; }

public:
    OrgFreedesktopURfkillKillswitchInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopURfkillKillswitchInterface();

    Q_PROPERTY(int state READ state)
    inline int state() const
    { return qvariant_cast< int >(property("state")); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void StateChanged();
};

#endif
