/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -p URfkillDeviceInterface /home/odroid/lomiri/libqtdbusmock-git/src/libqtdbusmock/data/org.freedesktop.URfkill.Device.xml
 *
 * qdbusxml2cpp is Copyright (C) 2020 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef URFKILLDEVICEINTERFACE_H
#define URFKILLDEVICEINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.URfkill.Device
 */
class OrgFreedesktopURfkillDeviceInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.URfkill.Device"; }

public:
    OrgFreedesktopURfkillDeviceInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopURfkillDeviceInterface();

    Q_PROPERTY(bool hard READ hard)
    inline bool hard() const
    { return qvariant_cast< bool >(property("hard")); }

    Q_PROPERTY(uint index READ index)
    inline uint index() const
    { return qvariant_cast< uint >(property("index")); }

    Q_PROPERTY(QString name READ name)
    inline QString name() const
    { return qvariant_cast< QString >(property("name")); }

    Q_PROPERTY(bool platform READ platform)
    inline bool platform() const
    { return qvariant_cast< bool >(property("platform")); }

    Q_PROPERTY(bool soft READ soft)
    inline bool soft() const
    { return qvariant_cast< bool >(property("soft")); }

    Q_PROPERTY(uint type READ type)
    inline uint type() const
    { return qvariant_cast< uint >(property("type")); }

public Q_SLOTS: // METHODS
Q_SIGNALS: // SIGNALS
    void Changed();
};

#endif
