/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -p URfkillInterface /home/odroid/lomiri/libqtdbusmock-git/src/libqtdbusmock/data/org.freedesktop.URfkill.xml
 *
 * qdbusxml2cpp is Copyright (C) 2020 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef URFKILLINTERFACE_H
#define URFKILLINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>

/*
 * Proxy class for interface org.freedesktop.URfkill
 */
class OrgFreedesktopURfkillInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.URfkill"; }

public:
    OrgFreedesktopURfkillInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopURfkillInterface();

    Q_PROPERTY(QString DaemonVersion READ daemonVersion)
    inline QString daemonVersion() const
    { return qvariant_cast< QString >(property("DaemonVersion")); }

    Q_PROPERTY(bool KeyControl READ keyControl)
    inline bool keyControl() const
    { return qvariant_cast< bool >(property("KeyControl")); }

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<bool> Block(uint type, bool block)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(type) << QVariant::fromValue(block);
        return asyncCallWithArgumentList(QStringLiteral("Block"), argumentList);
    }

    inline QDBusPendingReply<bool> BlockIdx(uint index, bool block)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(index) << QVariant::fromValue(block);
        return asyncCallWithArgumentList(QStringLiteral("BlockIdx"), argumentList);
    }

    inline QDBusPendingReply<QList<QDBusObjectPath> > EnumerateDevices()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("EnumerateDevices"), argumentList);
    }

    inline QDBusPendingReply<bool> FlightMode(bool block)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(block);
        return asyncCallWithArgumentList(QStringLiteral("FlightMode"), argumentList);
    }

    inline QDBusPendingReply<uint> Inhibit(const QString &reason)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(reason);
        return asyncCallWithArgumentList(QStringLiteral("Inhibit"), argumentList);
    }

    inline QDBusPendingReply<bool> IsFlightMode()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("IsFlightMode"), argumentList);
    }

    inline QDBusPendingReply<bool> IsInhibited()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("IsInhibited"), argumentList);
    }

    inline QDBusPendingReply<> Uninhibit(uint inhibit_cookie)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(inhibit_cookie);
        return asyncCallWithArgumentList(QStringLiteral("Uninhibit"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void DeviceAdded(const QDBusObjectPath &device);
    void DeviceChanged(const QDBusObjectPath &device);
    void DeviceRemoved(const QDBusObjectPath &device);
    void FlightModeChanged(bool flight_mode);
    void UrfkeyPressed(int keycode);
};

#endif
