/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -i libqtdbusmock/MockInterfaceClasses.h -p MockInterface /home/odroid/lomiri/libqtdbusmock-git/src/libqtdbusmock/data/org.freedesktop.DBus.Mock.xml
 *
 * qdbusxml2cpp is Copyright (C) 2020 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef MOCKINTERFACE_H
#define MOCKINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "libqtdbusmock/MockInterfaceClasses.h"

/*
 * Proxy class for interface org.freedesktop.DBus.Mock
 */
class OrgFreedesktopDBusMockInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.DBus.Mock"; }

public:
    OrgFreedesktopDBusMockInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgFreedesktopDBusMockInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<> AddMethod(const QString &interface, const QString &name, const QString &in_sig, const QString &out_sig, const QString &code)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(interface) << QVariant::fromValue(name) << QVariant::fromValue(in_sig) << QVariant::fromValue(out_sig) << QVariant::fromValue(code);
        return asyncCallWithArgumentList(QStringLiteral("AddMethod"), argumentList);
    }

    inline QDBusPendingReply<> AddMethods(const QString &interface, const QList<QtDBusMock::Method> &methods)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(interface) << QVariant::fromValue(methods);
        return asyncCallWithArgumentList(QStringLiteral("AddMethods"), argumentList);
    }

    inline QDBusPendingReply<> AddObject(const QString &path, const QString &interface, const QVariantMap &properties, const QList<QtDBusMock::Method> &methods)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(path) << QVariant::fromValue(interface) << QVariant::fromValue(properties) << QVariant::fromValue(methods);
        return asyncCallWithArgumentList(QStringLiteral("AddObject"), argumentList);
    }

    inline QDBusPendingReply<> AddProperties(const QString &interface, const QVariantMap &properties)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(interface) << QVariant::fromValue(properties);
        return asyncCallWithArgumentList(QStringLiteral("AddProperties"), argumentList);
    }

    inline QDBusPendingReply<> AddProperty(const QString &interface, const QString &name, const QDBusVariant &value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(interface) << QVariant::fromValue(name) << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("AddProperty"), argumentList);
    }

    inline QDBusPendingReply<> AddTemplate(const QString &xtemplate, const QVariantMap &parameters)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(xtemplate) << QVariant::fromValue(parameters);
        return asyncCallWithArgumentList(QStringLiteral("AddTemplate"), argumentList);
    }

    inline QDBusPendingReply<> ClearCalls()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("ClearCalls"), argumentList);
    }

    inline QDBusPendingReply<> EmitSignal(const QString &interface, const QString &name, const QString &signature, const QVariantList &args)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(interface) << QVariant::fromValue(name) << QVariant::fromValue(signature) << QVariant::fromValue(args);
        return asyncCallWithArgumentList(QStringLiteral("EmitSignal"), argumentList);
    }

    inline QDBusPendingReply<QList<QtDBusMock::NamedMethodCall> > GetCalls()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("GetCalls"), argumentList);
    }

    inline QDBusPendingReply<QList<QtDBusMock::MethodCall> > GetMethodCalls(const QString &method)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(method);
        return asyncCallWithArgumentList(QStringLiteral("GetMethodCalls"), argumentList);
    }

    inline QDBusPendingReply<> RemoveObject(const QString &path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(path);
        return asyncCallWithArgumentList(QStringLiteral("RemoveObject"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void MethodCalled(const QString &name, const QVariantList &args);
};

#endif
