/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Command line was: qdbusxml2cpp -N -m -c NetworkManagerMockInterface -i libqtdbusmock/ExportInterfaces.h -p NetworkManagerMockInterface /home/odroid/lomiri/libqtdbusmock-git/src/libqtdbusmock/data/nm-manager-mock.xml
 *
 * qdbusxml2cpp is Copyright (C) 2020 The Qt Company Ltd.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef NETWORKMANAGERMOCKINTERFACE_H
#define NETWORKMANAGERMOCKINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "libqtdbusmock/ExportInterfaces.h"

/*
 * Proxy class for interface org.freedesktop.DBus.Mock
 */
class NetworkManagerMockInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.freedesktop.DBus.Mock"; }

public:
    NetworkManagerMockInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~NetworkManagerMockInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString> AddAccessPoint(const QString &dev_path, const QString &ap_name, const QString &ssid, const QString &hw_address, uint mode, uint frequency, uint rate, uchar strength, uint security)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(dev_path) << QVariant::fromValue(ap_name) << QVariant::fromValue(ssid) << QVariant::fromValue(hw_address) << QVariant::fromValue(mode) << QVariant::fromValue(frequency) << QVariant::fromValue(rate) << QVariant::fromValue(strength) << QVariant::fromValue(security);
        return asyncCallWithArgumentList(QStringLiteral("AddAccessPoint"), argumentList);
    }

    inline QDBusPendingReply<QString> AddActiveConnection(const QStringList &devices, const QString &connection_device, const QString &specific_object, const QString &active_connection_name, uint state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(devices) << QVariant::fromValue(connection_device) << QVariant::fromValue(specific_object) << QVariant::fromValue(active_connection_name) << QVariant::fromValue(state);
        return asyncCallWithArgumentList(QStringLiteral("AddActiveConnection"), argumentList);
    }

    inline QDBusPendingReply<QString> AddDeviceConnection(const QString &device_name, const QtDBusMock::VariantDictMap &settings)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_name) << QVariant::fromValue(settings);
        return asyncCallWithArgumentList(QStringLiteral("AddDeviceConnection"), argumentList);
    }

    inline QDBusPendingReply<QString> AddEthernetDevice(const QString &device_name, const QString &iface_name, int state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_name) << QVariant::fromValue(iface_name) << QVariant::fromValue(state);
        return asyncCallWithArgumentList(QStringLiteral("AddEthernetDevice"), argumentList);
    }

    inline QDBusPendingReply<QString> AddWiFiConnection(const QString &device_name, const QString &connection_name, const QString &ssid, const QString &key_mgmt)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_name) << QVariant::fromValue(connection_name) << QVariant::fromValue(ssid) << QVariant::fromValue(key_mgmt);
        return asyncCallWithArgumentList(QStringLiteral("AddWiFiConnection"), argumentList);
    }

    inline QDBusPendingReply<QString> AddWiFiDevice(const QString &device_name, const QString &interface_name, int state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_name) << QVariant::fromValue(interface_name) << QVariant::fromValue(state);
        return asyncCallWithArgumentList(QStringLiteral("AddWiFiDevice"), argumentList);
    }

    inline QDBusPendingReply<> RemoveAccessPoint(const QString &device_path, const QString &access_point_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_path) << QVariant::fromValue(access_point_path);
        return asyncCallWithArgumentList(QStringLiteral("RemoveAccessPoint"), argumentList);
    }

    inline QDBusPendingReply<> RemoveActiveConnection(const QString &device_path, const QString &active_connection_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_path) << QVariant::fromValue(active_connection_path);
        return asyncCallWithArgumentList(QStringLiteral("RemoveActiveConnection"), argumentList);
    }

    inline QDBusPendingReply<> RemoveWifiConnection(const QString &device_path, const QString &connection_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_path) << QVariant::fromValue(connection_path);
        return asyncCallWithArgumentList(QStringLiteral("RemoveWifiConnection"), argumentList);
    }

    inline QDBusPendingReply<> SetConnectivity(uint connectivity)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(connectivity);
        return asyncCallWithArgumentList(QStringLiteral("SetConnectivity"), argumentList);
    }

    inline QDBusPendingReply<> SetDeviceActive(const QString &device_path, const QString &connection_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_path) << QVariant::fromValue(connection_path);
        return asyncCallWithArgumentList(QStringLiteral("SetDeviceActive"), argumentList);
    }

    inline QDBusPendingReply<> SetDeviceDisconnected(const QString &device_path)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(device_path);
        return asyncCallWithArgumentList(QStringLiteral("SetDeviceDisconnected"), argumentList);
    }

    inline QDBusPendingReply<> SetGlobalConnectionState(uint state)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(state);
        return asyncCallWithArgumentList(QStringLiteral("SetGlobalConnectionState"), argumentList);
    }

    inline QDBusPendingReply<> SetProperty(const QString &path, const QString &iface, const QString &name, const QDBusVariant &value)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(path) << QVariant::fromValue(iface) << QVariant::fromValue(name) << QVariant::fromValue(value);
        return asyncCallWithArgumentList(QStringLiteral("SetProperty"), argumentList);
    }

    inline QDBusPendingReply<QString> SettingsAddConnection(const QtDBusMock::VariantDictMap &settings)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(settings);
        return asyncCallWithArgumentList(QStringLiteral("SettingsAddConnection"), argumentList);
    }

Q_SIGNALS: // SIGNALS
};

#endif
